@@ -1,9 +1,9 @@
 function _aws_cdk_aws_iot_actions_FirehoseStreamRecordSeparator(p) {
 }
-function _aws_cdk_aws_iot_actions_CloudWatchLogsActionProps(p) {
-}
 function _aws_cdk_aws_iot_actions_CloudWatchPutMetricActionProps(p) {
 }
+function _aws_cdk_aws_iot_actions_CloudWatchLogsActionProps(p) {
+}
 function _aws_cdk_aws_iot_actions_CommonActionProps(p) {
 }
 function _aws_cdk_aws_iot_actions_CloudWatchPutMetricAction(p) {
@@ -12,6 +12,8 @@ function _aws_cdk_aws_iot_actions_LambdaFunctionAction(p) {
 }
 function _aws_cdk_aws_iot_actions_CloudWatchLogsAction(p) {
 }
+function _aws_cdk_aws_iot_actions_FirehoseStreamAction(p) {
+}
 function _aws_cdk_aws_iot_actions_FirehoseStreamActionProps(p) {
     if (p == null)
         return;
@@ -22,8 +24,6 @@ function _aws_cdk_aws_iot_actions_FirehoseStreamActionProps(p) {
 }
 function _aws_cdk_aws_iot_actions_S3PutObjectAction(p) {
 }
-function _aws_cdk_aws_iot_actions_FirehoseStreamAction(p) {
-}
 function _aws_cdk_aws_iot_actions_S3PutObjectActionProps(p) {
 }
 function print(name, deprecationMessage) {
@@ -41,5 +41,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_iot_actions_FirehoseStreamRecordSeparator, _aws_cdk_aws_iot_actions_CloudWatchLogsActionProps, _aws_cdk_aws_iot_actions_CloudWatchPutMetricActionProps, _aws_cdk_aws_iot_actions_CommonActionProps, _aws_cdk_aws_iot_actions_CloudWatchPutMetricAction, _aws_cdk_aws_iot_actions_LambdaFunctionAction, _aws_cdk_aws_iot_actions_CloudWatchLogsAction, _aws_cdk_aws_iot_actions_FirehoseStreamActionProps, _aws_cdk_aws_iot_actions_S3PutObjectAction, _aws_cdk_aws_iot_actions_FirehoseStreamAction, _aws_cdk_aws_iot_actions_S3PutObjectActionProps };
+module.exports = { print, _aws_cdk_aws_iot_actions_FirehoseStreamRecordSeparator, _aws_cdk_aws_iot_actions_CloudWatchPutMetricActionProps, _aws_cdk_aws_iot_actions_CloudWatchLogsActionProps, _aws_cdk_aws_iot_actions_CommonActionProps, _aws_cdk_aws_iot_actions_CloudWatchPutMetricAction, _aws_cdk_aws_iot_actions_LambdaFunctionAction, _aws_cdk_aws_iot_actions_CloudWatchLogsAction, _aws_cdk_aws_iot_actions_FirehoseStreamAction, _aws_cdk_aws_iot_actions_FirehoseStreamActionProps, _aws_cdk_aws_iot_actions_S3PutObjectAction, _aws_cdk_aws_iot_actions_S3PutObjectActionProps };
 module.exports.DeprecationError = DeprecationError;
